@@ -1,4 +1,6 @@
 import logging
+from pathlib import Path
+import json
 from http import HTTPStatus
 from typing import Optional
 
@@ -23,6 +25,7 @@ from cloudfoundry_client.v2.service_instances import ServiceInstanceManager as S
 from cloudfoundry_client.v2.service_keys import ServiceKeyManager
 from cloudfoundry_client.v2.service_plan_visibilities import ServicePlanVisibilityManager
 from cloudfoundry_client.v2.service_plans import ServicePlanManager as ServicePlanManagerV2
+from cloudfoundry_client.v2.spaces import SpaceManager as SpaceManagerV2
 
 from cloudfoundry_client.v3.apps import AppManager
 from cloudfoundry_client.v3.buildpacks import BuildpackManager
@@ -85,7 +88,7 @@ class V2(object):
         self.routes = RouteManager(target_endpoint, credential_manager)
         self.services = EntityManagerV2(target_endpoint, credential_manager, "/v2/services")
         self.shared_domains = EntityManagerV2(target_endpoint, credential_manager, "/v2/shared_domains")
-        self.spaces = EntityManagerV2(target_endpoint, credential_manager, "/v2/spaces")
+        self.spaces = SpaceManagerV2(target_endpoint, credential_manager)
         self.stacks = EntityManagerV2(target_endpoint, credential_manager, "/v2/stacks")
         self.user_provided_service_instances = EntityManagerV2(
             target_endpoint, credential_manager, "/v2/user_provided_service_instances"
@@ -120,8 +123,8 @@ class V3(object):
 
 class CloudFoundryClient(CredentialManager):
     def __init__(self, target_endpoint: str, client_id: str = "cf", client_secret: str = "", **kwargs):
-        """ "
-        :param target_endpoint :the target endpoint
+        """
+        :param target_endpoint :the target endpoint.
         :param client_id: the client_id
         :param client_secret: the client secret
         :param proxy: a dict object with entries http and https
@@ -206,6 +209,19 @@ class CloudFoundryClient(CredentialManager):
             log_stream.get("href") if log_stream is not None else None,
         )
 
+    @staticmethod
+    def build_from_cf_config(config_path: Optional[str] = None, **kwargs) -> 'CloudFoundryClient':
+        config = Path(config_path) if config_path else Path.home() / '.cf/config.json'
+        try:
+            with open(config) as f:
+                cf_config = json.load(f)
+        except Exception as e:
+            _logger.critical('Could not retrieve cf config: %s', e)
+            raise
+        client = CloudFoundryClient(cf_config['Target'], **kwargs)
+        client.init_with_token(cf_config['RefreshToken'])
+        return client
+
     @staticmethod
     def _resolve_login_endpoint(root_links):
         return (root_links.get("login") or root_links.get("uaa") or root_links.get("self"))["href"]
